@@ -61,6 +61,9 @@ elif test -n "$MIRROR"; then
 fi
 debvm-create -k "$SSH_KEYPATH.pub" -o "$IMAGE" -r "$RELEASE" "$@"
 
+# Many CPUs tend to cause test timeouts on tcg emulation.
+export OMP_THREAD_LIMIT=4
+
 SSH_PORT=2222
 timeout 600s debvm-run -s "$SSH_PORT" -i "$IMAGE" &
 set -- localhost
@@ -69,4 +72,4 @@ debvm-waitssh -t 540 "$SSH_PORT"
 run_ssh "$@" poweroff
 wait
 
-"$(dirname "$0")/shell_interaction.expect" -- -i "$IMAGE"
+"$(dirname "$0")/shell_interaction.expect" -- debvm-run -i "$IMAGE"
