@@ -43,6 +43,9 @@ ssh-keygen -f "$SSH_KEYPATH" -N ''
 
 debvm-create --sshkey="$SSH_KEYPATH.pub" -r jessie --size=3G -- --customize-hook="copy-in upgrade /usr/local/bin" http://archive.debian.org/debian
 
+# Many CPUs tend to cause test timeouts on tcg emulation.
+export OMP_THREAD_LIMIT=4
+
 SSH_PORT=2222
 for RELEASE in stretch buster bullseye bookworm trixie sid; do
 	timeout 15m debvm-run -s "$SSH_PORT" &
